# frozen_string_literal: true

module MrCommon
  module PreRegistrations
    class PreRegistrationsController < BaseController
      def index
        @pre_registration = PreRegistration.order(email: :asc)
      end

      def new
        @pre_registration = PreRegistration.new
      end

      def create
        @pre_registration = PreRegistration.new(pre_registration_params)

        if @pre_registration.save
          redirect_to pre_registrations_path, notice: "Pre-registration saved."
        else
          flash.now[:alert] = "There was a problem saving the pre-registration."
          render :new, status: :unprocessable_entity
        end
      end

      def destroy
        @pre_registration = PreRegistration.find(params[:id])

        if @pre_registration.destroy
          redirect_to pre_registrations_path, notice: "Pre-registration deleted."
        else
          redirect_to pre_registrations_path, notice: "There was a problem deleting the pre-registration."
        end
      end

      private

        def pre_registration_params
          params.require(
            :confirmed_registration
          ).permit(
            :email,
            :first_name,
            :last_name
          )
        end
    end
  end
end
