# frozen_string_literal: true

module MrCommon
  module Registrations
    class ExportController < BaseController
      # Generates CSV data and sends as file download.
      def index
        send_data(registrations_csv, filename: filename)
      end

      private

        def registrations_csv
          fields = csv_fields
          fields.delete(:pre_registered?) unless MrCommon.registration_confirmation_strategy == :pre_register

          CSVRenderer.new(
            collection: MrCommon::Registration.all,
            decorator: MrCommon::RegistrationDecorator,
            fields: fields
          ).render
        end

        def csv_fields
          [
            :first_name,
            :last_name,
            :email,
            :company_name,
            :telephone,
            :zip_code,
            :country,
            :pre_registered?,
            :confirmed?,
            :created_at,
            :updated_at
          ]
        end

        def filename
          "Registrations-#{Date.today}.csv"
        end
    end
  end
end
