# frozen_string_literal: true

module MrCommon
  module Registrations
    # Implements public Registration actions available from the landing page.
    class PublicController < PublicBaseController
      def new
        @registration = Registration.new
      end

      def create
        @registration = Registration.new(registration_params)
        @registration.confirmed = true if should_confirm_registration?

        if @registration.save
          send_notification
          redirect_to registrations_success_index_path, notice: MrCommon.registration_success_notice
        else
          flash.now[:alert] = MrCommon.registration_failure_alert if MrCommon.registration_failure_alert.present?
          render :new, status: :unprocessable_entity
        end
      end

      private

        def should_confirm_registration?
          case MrCommon.registration_confirmation_strategy
          when :auto
            true
          when :pre_register
            PreRegistration.exists_for?(@registration)
          when :manual
            false
          else
            false
          end
        end

        def send_notification
          if @registration.confirmed?
            RegistrationMailer.confirmed_registration(@registration.id).deliver_now
          else
            RegistrationMailer.unconfirmed_registration(@registration.id).deliver_now
          end
        end

        def registration_params
          params.require(
            :registration
          ).permit(
            :first_name,
            :last_name,
            :email,
            :company_name,
            :telephone,
            :job_title,
            :contact_via_email,
            :contact_via_phone,
          )
        end
    end
  end
end
