# frozen_string_literal: true

module MrCommon
  module Registrations
    # Admin CRUD for Registrations.
    class RegistrationsController < BaseController
      def index
        @registrations = Registration.order(first_name: :asc, last_name: :asc)
      end

      def show
        @registration = Registration.find(params[:id])
      end

      def new
        @registration = Registration.new
      end

      def create
        @registration = Registration.new(registration_params)

        if @registration.save
          redirect_to registrations_path, notice: "Registration saved."
        else
          flash.now[:alert] = MrCommon.registration_failure_alert
          render :new, status: :unprocessable_entity
        end
      end

      def edit
        @registration = Registration.find(params[:id])
      end

      def update
        @registration = Registration.find(params[:id])

        if @registration.update(registration_params)
          redirect_to @registration, notice: "Registration saved."
        else
          flash.now[:alert] = MrCommon.registration_failure_alert
          render :new, status: :unprocessable_entity
        end
      end

      def destroy
        @registration = Registration.find(params[:id])

        if @registration.destroy
          redirect_to registrations_path, notice: "Registration destroyed."
        else
          redirect_to @registration, alert: "Unable to destroy Registration."
        end
      end

      private

        def registration_params
          params.require(
            :registration
          ).permit(
            :first_name,
            :last_name,
            :email,
            :company_name,
            :telephone,
            :job_title,
            :confirmed,
            :contact_via_email,
            :contact_via_phone,
          )
        end
    end
  end
end
