# frozen_string_literal: true

require_dependency "mr_common/application_record"

module MrCommon
  class Registration < ApplicationRecord
    include MrCommon::CSVExportable

    validates :first_name, presence: true
    validates :last_name, presence: true
    validates :email, presence: true, format: Pattern.email
    validates :company_name, presence: true
    validates :telephone, presence: true, format: Pattern.phone_number
    validates :job_title, presence: true
    validates :contact_via_email, inclusion: [true, false]
    validates :contact_via_phone, inclusion: [true, false]

    validate :telephone_length

    private

      def telephone_length
        digits = telephone.gsub(/\D+/, "")
        errors.add(:telephone, "must be longer") if digits.length < 7
      end
  end
end
