# frozen_string_literal: true

require "mr_common/engine"
require "icalendar"
require "icalendar/tzinfo"
require "carmen"
require "csv"

module MrCommon
  # Host integration configs
  cattr_accessor :base_controller_name, default: "::ApplicationController"
  cattr_accessor :user_class_name, default: "::User"
  cattr_accessor :authentication_method_name, default: :authenticate_user!
  cattr_accessor :current_user_method_name, default: :current_user
  cattr_accessor :current_user_authorization_method_name, default: :mr_common_admin?
  cattr_accessor :logout_path_helper, default: :destroy_user_session_path
  cattr_accessor :logout_path_method, default: :delete
  cattr_accessor :sign_in_path_helper, default: :new_user_session_path
  cattr_accessor :host_app_layout, default: "application"

  # Feature flags

  # :auto         - All Registrations will be automatically confirmed (default)
  # :pre_register - Registrations will be confirmed automatically if a PreRegistration is found
  # :manual       - An admin will need to log in and click the confirm button for each registration
  cattr_accessor :registration_confirmation_strategy, default: :auto

  # Look and feel
  cattr_accessor :registration_success_notice, default: "Registration completed successfully."
  cattr_accessor :registration_failure_alert, default: "Registration could not be completed."
  cattr_accessor :registration_confirmed_subject, default: "Your registration is confirmed."
  cattr_accessor :registration_unconfirmed_subject, default: "Thanks for your interest."
  cattr_accessor :registration_revoked_subject, default: "Your registration is not confirmed."
  cattr_accessor :title, default: "Mreach Common Utils"

  class << self
    def base_controller_class
      base_controller_name.constantize
    end

    def user_class
      user_class_name.constantize
    end
  end
end
